"""
Our little helpers
"""

# Standard Library
import re


def string_cleanup(string: str) -> str:
    """
    Clean up a string by removing JS, CSS and Head tags

    :param string:
    :type string:
    :return:
    :rtype:
    """

    re_head = re.compile(
        pattern=r"<\s*head[^>]*>.*?<\s*/\s*head\s*>", flags=re.S | re.I
    )
    re_script = re.compile(
        pattern=r"<\s*script[^>]*>.*?<\s*/\s*script\s*>", flags=re.S | re.I
    )
    re_css = re.compile(
        pattern=r"<\s*style[^>]*>.*?<\s*/\s*style\s*>", flags=re.S | re.I
    )

    # Strip unwanted content (JS, CSS, HTML-Head)
    string = re_head.sub(repl="", string=string)
    string = re_script.sub(repl="", string=string)
    string = re_css.sub(repl="", string=string)

    return string



"""
Test the apps' template tags
"""

# Django
from django.template import Context, Template
from django.test import TestCase

# AA Bulletin Board
from aa_bulletin_board import __version__


class TestVersionedStatic(TestCase):
    """
    Test aa_bulletin_board_static template tag
    """

    def test_versioned_static(self) -> None:
        """
        Test versioned static template tag

        :return:
        :rtype:
        """

        context = Context({"version": __version__})
        template_to_render = Template(
            template_string=(
                "{% load aa_bulletin_board %}"
                "{% aa_bulletin_board_static 'aa_bulletin_board/css/aa-bulletin-board.min.css' %}"  # pylint: disable=line-too-long
            )
        )

        rendered_template = template_to_render.render(context=context)

        self.assertInHTML(
            needle=f'/static/aa_bulletin_board/css/aa-bulletin-board.min.css?v={context["version"]}',  # pylint: disable=line-too-long
            haystack=rendered_template,
        )
